@@ -43,8 +43,6 @@
 #include "mibank.h"
 #include "mipointer.h"
 #include "mibstore.h"
-#define _XF86MISC_SERVER_
-#include <X11/extensions/xf86misc.h>
 
 #include "sisusb_regs.h"
 #include "sisusb_dac.h"
@@ -92,24 +90,6 @@ static SymTabRec SISUSBChipsets[] = {
     { -1,              NULL }
 };
 
-static const char *fbSymbols[] = {
-    "fbPictureInit",
-    "fbScreenInit",
-    NULL
-};
-
-static const char *shadowSymbols[] = {
-    "ShadowFBInit",
-    NULL
-};
-
-static const char *ramdacSymbols[] = {
-    "xf86CreateCursorInfoRec",
-    "xf86DestroyCursorInfoRec",
-    "xf86InitCursor",
-    NULL
-};
-
 #ifdef XFree86LOADER
 
 static MODULESETUPPROTO(sisusbSetup);
@@ -145,7 +125,6 @@ sisusbSetup(pointer module, pointer opts, int *errmaj, int *errmin)
     if(!setupDone) {
        setupDone = TRUE;
        xf86AddDriver(&SISUSB, module, SISUSB_HaveDriverFuncs);
-       LoaderRefSymLists(fbSymbols, shadowSymbols, ramdacSymbols, NULL);
        return (pointer)TRUE;
     }
 
@@ -482,11 +461,7 @@ SISUSBProbe(DriverPtr drv, int flags)
             pScrn->LeaveVT          = SISUSBLeaveVT;
             pScrn->FreeScreen       = SISUSBFreeScreen;
             pScrn->ValidMode        = SISUSBValidMode;
-#ifdef X_XF86MiscPassMessage
-	    if(xf86GetVersion() >= XF86_VERSION_NUMERIC(4,3,99,2,0)) {
-	       pScrn->HandleMessage = SISUSBHandleMessage;
-            }
-#endif
+
             foundScreen = TRUE;
         }
 
@@ -829,7 +804,7 @@ SISUSBPreInit(ScrnInfoPtr pScrn, int flags)
     }
 #endif
 #else
-#if XF86_VERSION_CURRENT >= XF86_VERSION_NUMERIC(4,2,99,0,0)
+#if XF86_VERSION_CURRENT >= XF86_VERSION_NUMERIC(4,2,99,0)
     if(xf86GetVersion() != XF86_VERSION_CURRENT) {
        xf86DrvMsg(pScrn->scrnIndex, X_WARNING,
          "This driver binary is not compiled for this version of " SISUSBMYSERVERNAME "\n");
@@ -880,8 +855,6 @@ SISUSBPreInit(ScrnInfoPtr pScrn, int flags)
        return FALSE;
     }
 
-    xf86LoaderReqSymLists(ramdacSymbols, NULL);
-
     /* Set pScrn->monitor */
     pScrn->monitor = pScrn->confScreen->monitor;
 
@@ -1450,7 +1423,6 @@ SISUSBPreInit(ScrnInfoPtr pScrn, int flags)
         SISUSBFreeRec(pScrn);
         return FALSE;
     }
-    xf86LoaderReqSymLists(fbSymbols, NULL);
 
     /* Load shadowfb (if needed) */
     if(pSiSUSB->ShadowFB) {
@@ -1460,7 +1432,6 @@ SISUSBPreInit(ScrnInfoPtr pScrn, int flags)
 	  SISUSBFreeRec(pScrn);
           return FALSE;
        }
-       xf86LoaderReqSymLists(shadowSymbols, NULL);
     }
 
     pSiSUSB->UseVESA = 0;
@@ -2001,7 +1972,7 @@ SISUSBScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
     pSiSUSB->xv_sisdirectunlocked = 0;
 
 #ifdef SIS_GLOBAL_ENABLEXV
-#if (XF86_VERSION_CURRENT >= XF86_VERSION_NUMERIC(4,3,99,0,0)) || (defined(XvExtension))
+#if (XF86_VERSION_CURRENT >= XF86_VERSION_NUMERIC(4,3,99,0)) || (defined(XvExtension))
     if(!pSiSUSB->NoXvideo) {
        SISUSBInitVideo(pScreen);
     }
